@@ -11,41 +11,37 @@ from dash.exceptions import PreventUpdate
 from flask import session
 from flask_caching.backends import FileSystemCache
 from more_itertools import unique_everseen
+from dash import Dash
 
 
-# region Callback blueprint
+# region New syntax
 
-class CallbackBlueprint:
-    """
-    The CallbackBlueprint (CB) class acts as a proxy for the Dash app object in the context of callback registration.
-    To bind the callbacks registered on a CB to a Dash app, the "register" function must be called.
-    """
+class DashExtension(Dash):
 
-    def __init__(self):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self.callbacks = []
 
-    def callback(self, outputs, inputs, states=None):
-        """
-        This method mirrors the callback decorator of the Dash app object, but simply caches the inputs.
-        """
-        outputs, inputs, states = _as_list(outputs), _as_list(inputs), _as_list(states)
-        self.callbacks.append(dict(outputs=outputs, inputs=inputs, states=states))
+    def callback(self, *args, **kwargs):
+        # NOTE: Args can be {Output, Input, State} while kwargs can be {prevent_initial_update, cache}
+        self.callbacks.append(dict(args=args, kwargs=kwargs))
 
         def cache_func(func):
             self.callbacks[-1]["callback"] = func
 
         return cache_func
 
-    def register(self, dash_app):
-        """
-        This method registers the cached callbacks on the Dash app object.
-        """
-        callbacks = self._resolve_callbacks()
+    def _setup_server(self):
+        # Register the callbacks.
+        callbacks = list(self._resolve_callbacks())
         for callback in callbacks:
-            _register_callback(dash_app, callback)
+            outputs = callback["outputs"][0] if len(callback["outputs"]) == 1 else callback["outputs"]
+            super().callback(outputs, callback["inputs"], callback["states"])(callback["callback"])
         # Set session secret. Used by some subclasses.
-        if not dash_app.server.secret_key:
-            dash_app.server.secret_key = secrets.token_urlsafe(16)
+        if not self.server.secret_key:
+            self.server.secret_key = secrets.token_urlsafe(16)
+        # Proceed as normally.
+        super()._setup_server()
 
     def _resolve_callbacks(self):
         """
@@ -63,11 +59,6 @@ def _get_session_id(session_key=None):
     return session.get(session_key)
 
 
-def _register_callback(dash_app, callback):
-    outputs = callback["outputs"][0] if len(callback["outputs"]) == 1 else callback["outputs"]
-    dash_app.callback(outputs, callback["inputs"], callback["states"])(callback["callback"])
-
-
 def _as_list(item):
     if item is None:
         return []
@@ -78,10 +69,6 @@ def _create_callback_id(item):
     return "{}.{}".format(item.component_id, item.component_property)
 
 
-# endregion
-
-# region Callback cache
-
 class Trigger(Input):
     """
      Like an Input, a trigger can trigger a callback, but it's values it not included in the resulting function call.
@@ -91,6 +78,18 @@ class Trigger(Input):
         super().__init__(component_id, component_property)
 
 
+# endregion
+
+class DashExtensionImplementation(DashExtension):
+
+    def _resolve_callbacks(self):
+
+
+        return self.callbacks
+
+
+# region Callback cache
+
 class CallbackCache(CallbackBlueprint):
     """
     The CallbackCache (CB) class acts as a proxy for the Dash app object in the context of callback registration. It
@@ -216,6 +215,51 @@ def _get_cache_id(func, output, args, session_check=None):
     return hashlib.md5(json.dumps(all_args).encode()).hexdigest()
 
 
+# endregion
+
+# region Callback blueprint
+
+class CallbackBlueprint:
+    """
+    The CallbackBlueprint (CB) class acts as a proxy for the Dash app object in the context of callback registration.
+    To bind the callbacks registered on a CB to a Dash app, the "register" function must be called.
+    """
+
+    def __init__(self):
+        self.callbacks = []
+
+    def callback(self, outputs, inputs, states=None):
+        """
+        This method mirrors the callback decorator of the Dash app object, but simply caches the inputs.
+        """
+        outputs, inputs, states = _as_list(outputs), _as_list(inputs), _as_list(states)
+        self.callbacks.append(dict(outputs=outputs, inputs=inputs, states=states))
+
+        def cache_func(func):
+            self.callbacks[-1]["callback"] = func
+
+        return cache_func
+
+    def register(self, dash_app):
+        """
+        This method registers the cached callbacks on the Dash app object.
+        """
+        callbacks = self._resolve_callbacks()
+        for callback in callbacks:
+            outputs = callback["outputs"][0] if len(callback["outputs"]) == 1 else callback["outputs"]
+            dash_app.callback(outputs, callback["inputs"], callback["states"])(callback["callback"])
+        # Set session secret. Used by some subclasses.
+        if not dash_app.server.secret_key:
+            dash_app.server.secret_key = secrets.token_urlsafe(16)
+
+    def _resolve_callbacks(self):
+        """
+         This method resolves the callbacks. While no modifications are performed in the base class, this is the method
+         that subclasses should target inject callback modifications.
+        """
+        return self.callbacks
+
+
 # endregion
 
 # region Callback grouper
